@@ -22,15 +22,16 @@
  */
 
 #ifdef HAVE_CONFIG_H
- #include <config.h> /* for GETTEXT_PACKAGE */
+#include <config.h>
 #endif
 
+#include <glib/gi18n-lib.h>
+
 #include "caja-open-terminal.h"
 
 #include <libcaja-extension/caja-menu-provider.h>
 #include <libcaja-extension/caja-configurable.h>
 
-#include <glib/gi18n-lib.h>
 #include <gtk/gtkicontheme.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkmain.h>
@@ -91,7 +92,7 @@ get_terminal_file_info (CajaFileInfo *file_info)
 	return ret;
 }
 
-char *
+static char *
 lookup_in_data_dir (const char *basename,
                     const char *data_dir)
 {
@@ -520,7 +521,7 @@ caja_open_terminal_get_background_items (CajaMenuProvider *provider,
 	}
 }
 
-GList *
+static GList *
 caja_open_terminal_get_file_items (CajaMenuProvider *provider,
                                    GtkWidget        *window,
                                    GList            *files)
