@@ -22,12 +22,12 @@
  */
 
 #ifdef HAVE_CONFIG_H
- #include <config.h>
+#include <config.h>
 #endif
 
-#include "caja-open-terminal.h"
+#include <glib/gi18n-lib.h>
 
-#include <libintl.h>
+#include "caja-open-terminal.h"
 
 static GType type_list[1];
 
@@ -38,9 +38,6 @@ caja_module_initialize (GTypeModule *module)
 
 	caja_open_terminal_register_type (module);
 	type_list[0] = CAJA_TYPE_OPEN_TERMINAL;
-
-	bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 }
 
 void
