@@ -21,29 +21,30 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
+#include <glib/gi18n-lib.h>
+
 #include <libcaja-extension/caja-extension-types.h>
 #include <libcaja-extension/caja-column-provider.h>
-#include <glib/gi18n-lib.h>
-#include "caja-nste.h"
 
+#include "caja-nste.h"
 
 void
 caja_module_initialize (GTypeModule*module)
 {
+	g_print ("Initializing caja-sendto extension\n");
 	caja_nste_register_type (module);
-
-	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 }
 
-
 void
 caja_module_shutdown (void)
 {
+	g_print ("Shutting down caja-sendto extension\n");
 }
 
-
 void
 caja_module_list_types (const GType **types,
 			    int          *num_types)
@@ -55,6 +56,3 @@ caja_module_list_types (const GType **types,
 
 	*num_types = 1;
 }
-
-
-
