@@ -21,9 +21,13 @@
  * Author:  Jader Henrique da Silva <vovozito@gmail.com>
  */
 
-#include "config.h"
-#include <string.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glib/gi18n-lib.h>
+
+#include <string.h>
 #include "nst-common.h"
 #include "caja-sendto-plugin.h"
 
@@ -46,9 +50,6 @@ gboolean init (NstPlugin *plugin)
 
 	g_print ("Init caja burn plugin\n");
 
-	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-
 	it = gtk_icon_theme_get_default ();
 	gtk_icon_theme_append_search_path (it, DATADIR "/brasero/icons");
 
@@ -163,12 +164,11 @@ gboolean send_files (NstPlugin *plugin,
 }
 
 static
-gboolean destroy (NstPlugin *plugin){
-
+gboolean destroy (NstPlugin *plugin)
+{
 	g_object_unref (burn);
 	burn = NULL;
 	return TRUE;
-
 }
 
 static
@@ -186,4 +186,3 @@ NstPluginInfo plugin_info = {
 };
 
 NST_INIT_PLUGIN (plugin_info)
-
