@@ -22,8 +22,12 @@
  *
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glib/gi18n-lib.h>
+
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib.h>
 #include "caja-sendto-plugin.h"
@@ -37,7 +41,6 @@ const gchar *COMPLETION_PROPS[] = {"name", "jid"};
 static GHashTable *jid_table = NULL;
 static gchar *iconset;
 
-
 DBusGProxy *proxy = NULL;
 
 /*
@@ -259,9 +262,6 @@ init (NstPlugin *plugin)
 {
 	g_print ("Init gajim plugin\n");
 
-	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-
 	/* connect to gajim dbus service */
 	jid_table = g_hash_table_new (g_str_hash, g_str_equal);
 	if (!init_dbus()) {
@@ -515,4 +515,3 @@ NstPluginInfo plugin_info = {
 };
 
 NST_INIT_PLUGIN (plugin_info)
-
