@@ -25,9 +25,12 @@
  *
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <glib/gi18n-lib.h>
+
 #include <libgupnp/gupnp.h>
 #include "caja-sendto-plugin.h"
 
@@ -167,7 +170,7 @@ device_proxy_unavailable_cb (GUPnPControlPoint *cp,
 }
 
 static void
-on_context_available (GUPnPContextManager *context_manager,
+on_context_available (GUPnPContextManager *manager,
                       GUPnPContext        *context,
                       gpointer             user_data)
 {
@@ -187,7 +190,7 @@ on_context_available (GUPnPContextManager *context_manager,
 	gssdp_resource_browser_set_active (GSSDP_RESOURCE_BROWSER (cp), TRUE);
 
 	/* Let context manager take care of the control point life cycle */
-	gupnp_context_manager_manage_control_point (context_manager, cp);
+	gupnp_context_manager_manage_control_point (manager, cp);
 	g_object_unref (cp);
 }
 
@@ -198,9 +201,6 @@ init (NstPlugin *plugin)
 	GtkCellRenderer *renderer;
 	char *upload_cmd;
 
-	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-
 	upload_cmd = g_find_program_in_path ("gupnp-upload");
 	if (upload_cmd == NULL)
 		return FALSE;
