@@ -23,6 +23,8 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n-lib.h>
+
 #include <libcaja-extension/caja-extension-types.h>
 #include <libcaja-extension/caja-column-provider.h>
 #include <libcaja-extension/caja-extension-types.h>
@@ -33,8 +35,6 @@
 
 #include "caja-share.h"
 
-#include <glib/gi18n-lib.h>
-
 #include <gio/gio.h>
 
 #include <gtk/gtk.h>
@@ -68,8 +68,7 @@ typedef struct {
   GtkWidget *main; /* Widget that holds all the rest.  Its "PropertyPage" GObject-data points to this PropertyPage structure */
 
   GtkWidget *checkbutton_share_folder;
-  GtkWidget *hbox_share_name;
-  GtkWidget *hbox_share_comment;
+  GtkWidget *box_share_content;
   GtkWidget *entry_share_name;
   GtkWidget *checkbutton_share_rw_ro;
   GtkWidget *checkbutton_share_guest_ok;
@@ -528,11 +527,7 @@ static void
 property_page_set_controls_sensitivity (PropertyPage *page,
 					gboolean      sensitive)
 {
-  gtk_widget_set_sensitive (page->entry_share_name, sensitive);
-  gtk_widget_set_sensitive (page->entry_share_comment, sensitive);
-  gtk_widget_set_sensitive (page->hbox_share_comment, sensitive);
-  gtk_widget_set_sensitive (page->hbox_share_name, sensitive);
-  gtk_widget_set_sensitive (page->checkbutton_share_rw_ro, sensitive);
+  gtk_widget_set_sensitive (page->box_share_content, sensitive);
 
   if (sensitive)
     {
@@ -699,7 +694,9 @@ create_property_page (CajaFileInfo *fileinfo)
 
 
   page->ui = gtk_builder_new ();
+#ifdef ENABLE_NLS
   gtk_builder_set_translation_domain (page->ui, GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
   g_assert (gtk_builder_add_from_file (page->ui,
               INTERFACES_DIR"/share-dialog.ui", &error));
 
@@ -712,8 +709,7 @@ create_property_page (CajaFileInfo *fileinfo)
 			  free_property_page_cb);
 
   page->checkbutton_share_folder = GTK_WIDGET (gtk_builder_get_object (page->ui,"checkbutton_share_folder"));
-  page->hbox_share_comment = GTK_WIDGET (gtk_builder_get_object (page->ui,"hbox_share_comment"));
-  page->hbox_share_name = GTK_WIDGET (gtk_builder_get_object (page->ui,"hbox_share_name"));
+  page->box_share_content = GTK_WIDGET (gtk_builder_get_object (page->ui,"box_share_content"));
   page->checkbutton_share_rw_ro = GTK_WIDGET (gtk_builder_get_object (page->ui,"checkbutton_share_rw_ro"));
   page->checkbutton_share_guest_ok = GTK_WIDGET (gtk_builder_get_object (page->ui,"checkbutton_share_guest_ok"));
   page->entry_share_name = GTK_WIDGET (gtk_builder_get_object (page->ui,"entry_share_name"));
@@ -724,8 +720,7 @@ create_property_page (CajaFileInfo *fileinfo)
 
   /* Sanity check so that we don't screw up the Glade file */
   g_assert (page->checkbutton_share_folder != NULL
-	    && page->hbox_share_comment != NULL
-	    && page->hbox_share_name != NULL
+	    && page->box_share_content != NULL
 	    && page->checkbutton_share_rw_ro != NULL
 	    && page->checkbutton_share_guest_ok != NULL
 	    && page->entry_share_name != NULL
@@ -1265,10 +1260,7 @@ caja_share_register_type (GTypeModule *module)
 void
 caja_module_initialize (GTypeModule  *module)
 {
-  /*g_print ("Initializing caja-share extension\n");*/
-
-  bindtextdomain(GETTEXT_PACKAGE, MATELOCALEDIR);
-  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+  g_print ("Initializing caja-share extension\n");
 
   caja_share_register_type (module);
 }
@@ -1277,7 +1269,7 @@ caja_module_initialize (GTypeModule  *module)
 void
 caja_module_shutdown   (void)
 {
-  /*g_print ("Shutting down caja-share extension\n");*/
+  g_print ("Shutting down caja-share extension\n");
   /* FIXME freeing */
 }
 
