@@ -1,9 +1,14 @@
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
+#include <glib/gi18n-lib.h>
+
 #include <string.h>
 #include <time.h>
 #include <sys/types.h>
 #include <sys/wait.h>
-#include <glib/gi18n-lib.h>
+
 #include "shares.h"
 
 #undef DEBUG_SHARES
@@ -25,8 +30,7 @@ static time_t refresh_timestamp;
 #define KEY_COMMENT "comment"
 #define KEY_ACL "usershare_acl"
 #define KEY_GUEST_OK "guest_ok"
-#define GROUP_ALLOW_GUESTS "global"
-#define KEY_ALLOW_GUESTS "usershare allow guests"
+
 
 /* Debugging flags */
 static gboolean throw_error_on_refresh;
