@@ -3,6 +3,7 @@
  *
  *  Copyright (C) 2005 Adam Israel
  *  Copyright (C) 2014 Stefano Karapetsas
+ *  Copyright (C) 2014-2021 MATE developers.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,21 +23,28 @@
  *           Stefano Karapetsas <stefano@karapetsas.com>
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
+#include <glib/gi18n-lib.h>
+
 #include <libcaja-extension/caja-extension-types.h>
 #include <libcaja-extension/caja-column-provider.h>
-#include <glib/gi18n-lib.h>
+
 #include "caja-wallpaper-extension.h"
 
 void
 caja_module_initialize (GTypeModule*module)
 {
+    g_print ("Initializing caja-wallpaper extension\n");
     caja_cwe_register_type (module);
 }
 
 void
 caja_module_shutdown (void)
 {
+    g_print ("Shutting down caja-wallpaper extension\n");
 }
 
 void
