@@ -2,6 +2,7 @@
  *  Caja xattr tags extension
  *
  *  Copyright (C) 2016 Felipe Barriga Richards
+ *  Copyright (C) 2016-2021 MATE developers.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,13 +21,19 @@
  *  Authors: Felipe Barriga Richards <spam@felipebarriga.cl>
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
+#include <glib/gi18n-lib.h>
+
 #include <string.h>
 #include <gio/gio.h>
-#include <glib/gi18n-lib.h>
+
 #include <libcaja-extension/caja-file-info.h>
 #include <libcaja-extension/caja-info-provider.h>
 #include <libcaja-extension/caja-column-provider.h>
+
 #include "caja-xattr-tags-extension.h"
 
 #define XATTR_TAGS_NAME "Xattr::Tags"
@@ -261,13 +268,13 @@ void
 caja_module_initialize (GTypeModule  *module)
 {
     g_print ("Initializing caja-xattr-tags extension\n");
-
     caja_xattr_tags_register_type (module);
 }
 
 void
 caja_module_shutdown (void)
 {
+    g_print ("Shutting down caja-xattr-tags extension\n");
 }
 
 /* List all the extension types.  */
